==> applet-web-boot-starter-0.0.5-sources.jar: cn/sinozg/applet/biz/system/vo/response/LoginInfoPageListResponse.java <==
package cn.sinozg.applet.biz.system.vo.response;

import io.swagger.v3.oas.annotations.media.Schema;
import java.time.LocalDateTime;

/**
 * @Author: xyb
 * @Description:
 * @Date: 2022-11-21 上午 10:51
 **/
public class LoginInfoPageListResponse {

    /** 访问ID */
    @Schema(description = "访问ID")
    private String id;

    /** 用户账号 */
    @Schema(description = "用户账号")
    private String userName;

    /** 登录IP地址 */
    @Schema(description = "登录IP地址")
    private String ipaddr;

    /** 登录地点 */
    @Schema(description = "登录地点")
    private String loginLocation;

    /** 浏览器类型 */
    @Schema(description = "浏览器类型")
    private String browser;

    /** 操作系统 */
    @Schema(description = "操作系统")
    private String os;

    /** 提示消息 */
    @Schema(description = "提示消息")
    private String msg;
    /** 登录类型，00 登录，01登出 */
    @Schema(description = "登录类型，00 登录，01登出")
    private String loginType;
    /** 访问时间 */
    @Schema(description = "访问时间")
    private LocalDateTime loginTime;

    /** 登录状态;0成功 1失败 */
    @Schema(description = "登录状态;0成功 1失败")
    private String dataStatus;

    /**
     * 获取 访问ID
     *
     * @return id 访问ID
     */
    public String getId() {
        return this.id;
    }

    /**
     * 设置 访问ID
     *
     * @param id 访问ID
     */
    public void setId(String id) {
        this.id = id;
    }

    /**
     * 获取 用户账号
     *
     * @return userName 用户账号
     */
    public String getUserName() {
        return this.userName;
    }

    /**
     * 设置 用户账号
     *
     * @param userName 用户账号
     */
    public void setUserName(String userName) {
        this.userName = userName;
    }

    /**
     * 获取 登录IP地址
     *
     * @return ipaddr 登录IP地址
     */
    public String getIpaddr() {
        return this.ipaddr;
    }

    /**
     * 设置 登录IP地址
     *
     * @param ipaddr 登录IP地址
     */
    public void setIpaddr(String ipaddr) {
        this.ipaddr = ipaddr;
    }

    /**
     * 获取 登录地点
     *
     * @return loginLocation 登录地点
     */
    public String getLoginLocation() {
        return this.loginLocation;
    }

    /**
     * 设置 登录地点
     *
     * @param loginLocation 登录地点
     */
    public void setLoginLocation(String loginLocation) {
        this.loginLocation = loginLocation;
    }

    /**
     * 获取 浏览器类型
     *
     * @return browser 浏览器类型
     */
    public String getBrowser() {
        return this.browser;
    }

    /**
     * 设置 浏览器类型
     *
     * @param browser 浏览器类型
     */
    public void setBrowser(String browser) {
        this.browser = browser;
    }

    /**
     * 获取 操作系统
     *
     * @return os 操作系统
     */
    public String getOs() {
        return this.os;
    }

    /**
     * 设置 操作系统
     *
     * @param os 操作系统
     */
    public void setOs(String os) {
        this.os = os;
    }

    /**
     * 获取 提示消息
     *
     * @return msg 提示消息
     */
    public String getMsg() {
        return this.msg;
    }

    /**
     * 设置 提示消息
     *
     * @param msg 提示消息
     */
    public void setMsg(String msg) {
        this.msg = msg;
    }

    /**
     * 获取 登录类型，00 登录，01登出
     *
     * @return loginType 登录类型，00 登录，01登出
     */
    public String getLoginType() {
        return this.loginType;
    }

    /**
     * 设置 登录类型，00 登录，01登出
     *
     * @param loginType 登录类型，00 登录，01登出
     */
    public void setLoginType(String loginType) {
        this.loginType = loginType;
    }

    /**
     * 获取 访问时间
     *
     * @return loginTime 访问时间
     */
    public LocalDateTime getLoginTime() {
        return this.loginTime;
    }

    /**
     * 设置 访问时间
     *
     * @param loginTime 访问时间
     */
    public void setLoginTime(LocalDateTime loginTime) {
        this.loginTime = loginTime;
    }

    /**
     * 获取 登录状态;0成功 1失败
     *
     * @return dataStatus 登录状态;0成功 1失败
     */
    public String getDataStatus() {
        return this.dataStatus;
    }

    /**
     * 设置 登录状态;0成功 1失败
     *
     * @param dataStatus 登录状态;0成功 1失败
     */
    public void setDataStatus(String dataStatus) {
        this.dataStatus = dataStatus;
    }
}

==> applet-web-boot-starter-3.2.2-sources.jar: cn/sinozg/applet/biz/system/vo/response/LoginInfoPageListResponse.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.biz.system.vo.response;

import cn.sinozg.applet.common.annotation.DictTrans;
import cn.sinozg.applet.common.enums.DictType;
import io.swagger.v3.oas.annotations.media.Schema;
import java.time.LocalDateTime;

/**
 * @Author: xyb
 * @Description:
 * @Date: 2022-11-21 上午 10:51
 **/
public class LoginInfoPageListResponse {

    /** 访问ID */
    @Schema(description = "访问ID")
    private String id;

    /** 用户id */
    @Schema(description = "用户id")
    private String userId;

    /** 用户账号 */
    @Schema(description = "用户账号")
    private String userName;

    /** 登录IP地址 */
    @Schema(description = "登录IP地址")
    private String ipaddr;

    /** 登录地点 */
    @Schema(description = "登录地点")
    private String loginLocation;

    /** 浏览器类型 */
    @Schema(description = "浏览器类型")
    private String browser;

    /** 操作系统 */
    @Schema(description = "操作系统")
    private String os;

    /** 提示消息 */
    @Schema(description = "提示消息")
    private String msg;

    /** 登录类型，00 登录，01登出 */
    @Schema(description = "登录类型，00 登录，01登出")
    @DictTrans(type = DictType.LOGIN_TYPE)
    private String loginType;

    /** 访问时间 */
    @Schema(description = "访问时间")
    private LocalDateTime loginTime;

    /** 登录状态;0成功 1失败 */
    @Schema(description = "登录状态;0成功 1失败")
    @DictTrans(type = DictType.OPT_DATA_STATUS)
    private String dataStatus;

    /**
     * 获取 访问ID
     *
     * @return id 访问ID
     */
    public String getId() {
        return this.id;
    }

    /**
     * 设置 访问ID
     *
     * @param id 访问ID
     */
    public void setId(String id) {
        this.id = id;
    }

    /**
     * 获取 用户id
     *
     * @return userId 用户id
     */
    public String getUserId() {
        return this.userId;
    }

    /**
     * 设置 用户id
     *
     * @param userId 用户id
     */
    public void setUserId(String userId) {
        this.userId = userId;
    }

    /**
     * 获取 用户账号
     *
     * @return userName 用户账号
     */
    public String getUserName() {
        return this.userName;
    }

    /**
     * 设置 用户账号
     *
     * @param userName 用户账号
     */
    public void setUserName(String userName) {
        this.userName = userName;
    }

    /**
     * 获取 登录IP地址
     *
     * @return ipaddr 登录IP地址
     */
    public String getIpaddr() {
        return this.ipaddr;
    }

    /**
     * 设置 登录IP地址
     *
     * @param ipaddr 登录IP地址
     */
    public void setIpaddr(String ipaddr) {
        this.ipaddr = ipaddr;
    }

    /**
     * 获取 登录地点
     *
     * @return loginLocation 登录地点
     */
    public String getLoginLocation() {
        return this.loginLocation;
    }

    /**
     * 设置 登录地点
     *
     * @param loginLocation 登录地点
     */
    public void setLoginLocation(String loginLocation) {
        this.loginLocation = loginLocation;
    }

    /**
     * 获取 浏览器类型
     *
     * @return browser 浏览器类型
     */
    public String getBrowser() {
        return this.browser;
    }

    /**
     * 设置 浏览器类型
     *
     * @param browser 浏览器类型
     */
    public void setBrowser(String browser) {
        this.browser = browser;
    }

    /**
     * 获取 操作系统
     *
     * @return os 操作系统
     */
    public String getOs() {
        return this.os;
    }

    /**
     * 设置 操作系统
     *
     * @param os 操作系统
     */
    public void setOs(String os) {
        this.os = os;
    }

    /**
     * 获取 提示消息
     *
     * @return msg 提示消息
     */
    public String getMsg() {
        return this.msg;
    }

    /**
     * 设置 提示消息
     *
     * @param msg 提示消息
     */
    public void setMsg(String msg) {
        this.msg = msg;
    }

    /**
     * 获取 登录类型，00 登录，01登出
     *
     * @return loginType 登录类型，00 登录，01登出
     */
    public String getLoginType() {
        return this.loginType;
    }

    /**
     * 设置 登录类型，00 登录，01登出
     *
     * @param loginType 登录类型，00 登录，01登出
     */
    public void setLoginType(String loginType) {
        this.loginType = loginType;
    }

    /**
     * 获取 访问时间
     *
     * @return loginTime 访问时间
     */
    public LocalDateTime getLoginTime() {
        return this.loginTime;
    }

    /**
     * 设置 访问时间
     *
     * @param loginTime 访问时间
     */
    public void setLoginTime(LocalDateTime loginTime) {
        this.loginTime = loginTime;
    }

    /**
     * 获取 登录状态;0成功 1失败
     *
     * @return dataStatus 登录状态;0成功 1失败
     */
    public String getDataStatus() {
        return this.dataStatus;
    }

    /**
     * 设置 登录状态;0成功 1失败
     *
     * @param dataStatus 登录状态;0成功 1失败
     */
    public void setDataStatus(String dataStatus) {
        this.dataStatus = dataStatus;
    }

}
